;;; browse-url-firefox.el --- pass a URL to the firefox WWW browser
;	$Id: browse-url-firefox.el,v 1.1 2004/11/23 11:03:39 sthalau Exp $	

;: Copyright (C) 2004 by Graz University of Technology
;; Inffeldgasse 16c, A-8010 Graz, Austria.

;; Author: stefan thalauer  <sthalau@iicm.edu>
;; Keywords: hypertext, hypermedia

;; This file is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This file is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Commentary:

;; This package is based on `browse-url.el'

;; Function                           Browser     Earliest version
;; browse-url-firefox                 Firefox     1.0

;; Firefox can be get from:
;; <URL:http://www.mozilla.org/firefox/>.

;; Usage:

;; Put this in your `~/.emacs' or `emacs-private.el' file

;;  (require 'browse-url-firefoz)
;;  (setq browse-url-browser-function 'browse-url-firefox 
;; 					browse-url-firefox-new-tab t
;; 					browse-url-opera-background-page nil
;;  )

;;; Code:

(eval-when-compile (require 'browse-url))

(defcustom browse-url-firefox-program "firefox"
  "*The name by which to invoke Firefox."
  :type 'string
  :group 'browse-url)

(defcustom browse-url-firefox-arguments nil
  "*A list of strings to pass to Firefox as arguments."
  :type '(repeat (string :tag "Argument"))
  :group 'browse-url)

(defcustom browse-url-firefox-startup-arguments browse-url-firefox-arguments
  "*A list of strings to pass to Firefox when it starts up.
Defaults to the value of `browse-url-firefox-arguments' at the time
`browse-url' is loaded."
  :type '(repeat (string :tag "Argument"))
  :group 'browse-url)

(defcustom browse-url-firefox-new-tab t
  "*Whether to open up new windows in a page or a new window.
If non-nil, then open the URL in a new page rather than a new window if
`browse-url-firefox' is asked to open it in a new window."
  :type 'boolean
  :group 'browse-url)

;; (defcustom browse-url-firefox-background-page t
;;   "*Whether to open up new windows in background page or a new window .
;; If non-nil, then open the URL in a background page  rather than a new page if
;; `browse-url-firefox' is asked to open it in a new page."
;;   :type 'boolean
;;   :group 'browse-url)


;;;###autoload
(defun browse-url-firefox (url &optional new-window)
  "Ask the Firefox WWW browser to load URL.
Default to the URL around or before point.  The strings in variable
`browse-url-firefox-arguments' are also passed to Firefox.

When called interactively, if variable `browse-url-firefox-new-tab' is
non-nil, load the document in a new Firefox page, otherwise use a
random existing one.  A non-nil interactive prefix argument reverses
the effect of `browse-url-firefox-new-tab'.

If `browse-url-firefox-new-window-is-tab' is non-nil, then whenever a
document would otherwise be loaded in a new window, it is loaded in a
new tab in an existing window instead.

When called non-interactively, optional second argument NEW-WINDOW is
used instead of `browse-url-firefox-new-tab'."
  (interactive (browse-url-interactive-arg "URL: "))
  ;; URL encode any `confusing' characters in the URL.  This needs to
  ;; include at least commas; presumably also close parens.
  (while (string-match "[,)]" url)
    (setq url (replace-match
	       (format "%%%x" (string-to-char (match-string 0 url))) t t url)))
  (let* ((process-environment (browse-url-process-environment))
         (process
	  (apply 'start-process
		 (concat "firefox " url) nil
		 browse-url-firefox-program
		 (append
		  browse-url-firefox-arguments
		  (list "-remote"
			(concat "openURL("
				url
;; 				(if (browse-url-maybe-new-window
;; 				     new-window)
        (if browse-url-firefox-new-tab
;; 								(if browse-url-firefox-background-page
;; 										 ",background-page"
            ",new-tab"
          )
;; 							",new-window"))
				")"))))))
    (set-process-sentinel process
			  `(lambda (process change)
			     (browse-url-firefox-sentinel process ,url)))))

(defun browse-url-firefox-sentinel (process url)
  "Handle a change to the process communicating with Firefox."
  (or (eq (process-exit-status process) 0)
      (let* ((process-environment (browse-url-process-environment)))
	;; Firefox is not running - start it
	(message "Starting Firefox...")
	(apply 'start-process (concat "firefox " url) nil
	       browse-url-firefox-program
	       (append browse-url-firefox-startup-arguments (list url))))))



(provide 'browse-url-firefox)
;;; browse-url-firefox.el ends here
