;;; browse-url-opera.el --- pass a URL to the opera WWW browser
;	$Id: browse-url-opera.el,v 1.2 2003/10/20 12:43:56 sthalau Exp $	

;; Copyright (C) 2003  Free Software Foundation, Inc.
;; Inffeldgasse 16c, A-8010 Graz, Austria.

;; Author: stefan thalauer  <sthalau@iicm.edu>
;; Keywords: hypertext, hypermedia

;; This file is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This file is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Commentary:

;; This package is based on `browse-url.el'

;; Function                           Browser     Earliest version
;; browse-url-opera                   Opera       7.11

;; Opera can be get from:
;; <URL:http://www.opera.com/>.

;; Usage:

;; Put this in your `~/.emacs' or `emacs-private.el' file

;;  (require 'browse-url-opera)
;;  (setq browse-url-browser-function 'browse-url-opera 
;; 					browse-url-opera-new-page t
;; 					browse-url-opera-background-page nil
;;           )

;;; Code:

(eval-when-compile (require 'browse-url))


(defcustom browse-url-opera-program "opera"
  "*The name by which to invoke Opera."
  :type 'string
  :group 'browse-url)

(defcustom browse-url-opera-arguments nil
  "*A list of strings to pass to Opera as arguments."
  :type '(repeat (string :tag "Argument"))
  :group 'browse-url)

(defcustom browse-url-opera-startup-arguments browse-url-opera-arguments
  "*A list of strings to pass to Opera when it starts up.
Defaults to the value of `browse-url-opera-arguments' at the time
`browse-url' is loaded."
  :type '(repeat (string :tag "Argument"))
  :group 'browse-url)

(defcustom browse-url-opera-new-page t
  "*Whether to open up new windows in a page or a new window.
If non-nil, then open the URL in a new page rather than a new window if
`browse-url-opera' is asked to open it in a new window."
  :type 'boolean
  :group 'browse-url)

(defcustom browse-url-opera-background-page t
  "*Whether to open up new windows in background page or a new window .
If non-nil, then open the URL in a background page  rather than a new page if
`browse-url-opera' is asked to open it in a new page."
  :type 'boolean
  :group 'browse-url)


;;;###autoload
(defun browse-url-opera (url &optional new-window)
  "Ask the Opera WWW browser to load URL.
Default to the URL around or before point.  The strings in variable
`browse-url-opera-arguments' are also passed to Opera.

When called interactively, if variable `browse-url-opera-new-page' is
non-nil, load the document in a new Opera page, otherwise use a
random existing one.  A non-nil interactive prefix argument reverses
the effect of `browse-url-opera-new-page'.

If `browse-url-opera-new-window-is-tab' is non-nil, then whenever a
document would otherwise be loaded in a new window, it is loaded in a
new tab in an existing window instead.

When called non-interactively, optional second argument NEW-WINDOW is
used instead of `browse-url-opera-new-page'."
  (interactive (browse-url-interactive-arg "URL: "))
  ;; URL encode any `confusing' characters in the URL.  This needs to
  ;; include at least commas; presumably also close parens.
  (while (string-match "[,)]" url)
    (setq url (replace-match
	       (format "%%%x" (string-to-char (match-string 0 url))) t t url)))
  (let* ((process-environment (browse-url-process-environment))
         (process
	  (apply 'start-process
		 (concat "opera " url) nil
		 browse-url-opera-program
		 (append
		  browse-url-opera-arguments
		  (list "-remote"
			(concat "openURL("
				url
				(if (browse-url-maybe-new-window
				     new-window)
						(if browse-url-opera-new-page
								(if browse-url-opera-background-page
										 ",background-page"
									",new-page"
									)
							",new-window"))
				")"))))))
    (set-process-sentinel process
			  `(lambda (process change)
			     (browse-url-opera-sentinel process ,url)))))

(defun browse-url-opera-sentinel (process url)
  "Handle a change to the process communicating with Opera."
  (or (eq (process-exit-status process) 0)
      (let* ((process-environment (browse-url-process-environment)))
	;; Opera is not running - start it
	(message "Starting Opera...")
	(apply 'start-process (concat "opera " url) nil
	       browse-url-opera-program
	       (append browse-url-opera-startup-arguments (list url))))))



(provide 'browse-url-opera)
;;; browse-url-opera.el ends here
